
/**************************************************************************************************
*
*  Sailing Base
*
*   Version:      1.3.1 - April 2009
*   Author:       Christoph Wartmann / chair for caad - ETH Zürich  /  wartmann[at]arch.ethz.ch
*                 Etienne Ribeiro    / tutorial assistant caad      /  eribeiro[at]ethz.ch
*
*   Desc:         Collects all Data received by the XBee-Nodes.
*
***************************************************************************************************/ 



// var

PFont Font;
String comPort = "";
SerialProtocolLibrary messanger;
ArrayList arrNodes = new ArrayList();
ArrayList arrNodesValue1 = new ArrayList();
ArrayList arrNodesValue2 = new ArrayList();
ArrayList arrNodesValue3 = new ArrayList();
ArrayList arrNodesAneometerIntervall = new ArrayList(); // Aneometer Intervall
ArrayList arrNodesAneoIntervall = new ArrayList(); // (for control to list)
ArrayList arrNodesPressureDiff = new ArrayList(); // Pressure Difference
// Loggong to file
Log DataLogger;
boolean doDatalog = true;






// Setup

void setup () {
  
  // size
  size(560, 450);
  // Font
  Font = loadFont("Verdana-48.vlw");
  textFont(Font, 14);


  // DataLogger
  DataLogger = new Log ("datalog.txt");
  
  
  // Display
  Display_Setup ();
  
  
  // Initialize COM Port
  messanger = new SerialProtocolLibrary (this, comPort);
  messanger.setID (0); // ID = 0 means you send and receive commands to/from all nodes
  
  
  // Background
  background(0);
  
  
  // Aneometer Configuration:
  messanger.sendToNode (0, 'B', ""); // Request aneometer intervall length
  
}


// Draw

void draw () {
  
  Display_Draw ();
  
}












// SerialEvenet

void SerialEvent (String msgid, String cmd, String message) {

  
  // Check if node is already listed:
  if (arrNodes.indexOf (msgid) == -1) {

    arrNodes.add (msgid);
    arrNodesValue1.add ("0");
    arrNodesValue2.add ("0");
    arrNodesValue3.add ("0");
    arrNodesAneometerIntervall.add ("0");
    arrNodesPressureDiff.add ("0");
    println ("Node: " + msgid); // Console
    
  }
  int index = arrNodes.indexOf (msgid);


  // Check if node is already listed (Aneometer Intervall):
  if (arrNodesAneoIntervall.indexOf (msgid) == -1)
    arrNodesAneoIntervall.add (msgid);
  int aneoHorizontalIndex = arrNodesAneoIntervall.indexOf (msgid) * 90;
  

  // Switch  
  switch (cmd.charAt(0)) {
    
    case 's': // Display sensor data
    
      String[] arr = message.split(":");
      if (arr.length == 4) {
        arrNodesValue1.set (index, arr[0]);
        arrNodesValue2.set (index, arr[1]);
        arrNodesValue3.set (index, arr[2]);
        // arr[3] = time
      }
      long now = System.currentTimeMillis();
      if (doDatalog)
        DataLogger.Println(msgid + ":" + message.substring(0, message.lastIndexOf(":")) + ":" + now);  // sensor 5:[hz]:[t]:[p]:[zentel sekunde]
      break;
      
    case 'B': // Aneometer Intervall
    
      arrNodesAneometerIntervall.set (index, message);
      break;
      
    case 'Q': // Pressure Diff
    
      arrNodesPressureDiff.set (index, message);
      break;
      
    default:
      println ("message msgid=" + msgid + " cmd=" + cmd + " msg=" + message);
      break;
    
  }


  // Console:
  //println ("message: " + message);
  
}

